X-Git-Url: https://git.rapsys.eu/userbundle/blobdiff_plain/e0458c2d4d46e0c822a1f985388d7eb909019f6d..c10ada0bebaf63162b0db1866f643984bdadbb30:/Entity/User.php

diff --git a/Entity/User.php b/Entity/User.php
index 8fb4105..549b176 100644
--- a/Entity/User.php
+++ b/Entity/User.php
@@ -1,13 +1,25 @@
-<?php
+<?php declare(strict_types=1);
+
+/*
+ * this file is part of the rapsys packbundle package.
+ *
+ * (c) raphaël gertz <symfony@rapsys.eu>
+ *
+ * for the full copyright and license information, please view the license
+ * file that was distributed with this source code.
+ */
 
-// src/Rapsys/UserBundle/Entity/User.php
 namespace Rapsys\UserBundle\Entity;
 
-use Rapsys\UserBundle\Entity\Group;
-use Symfony\Component\Security\Core\User\UserInterface;
 use Doctrine\Common\Collections\ArrayCollection;
+use Symfony\Component\Security\Core\User\UserInterface;
+
 use Rapsys\UserBundle\Entity\Civility;
+use Rapsys\UserBundle\Entity\Group;
 
+/**
+ * User
+ */
 class User implements UserInterface, \Serializable {
 	/**
 	 * @var integer
@@ -44,6 +56,11 @@ class User implements UserInterface, \Serializable {
 	 */
 	protected $active;
 
+	/**
+	 * @var bool
+	 */
+	protected $disabled;
+
 	/**
 	 * @var \DateTime
 	 */
@@ -55,20 +72,24 @@ class User implements UserInterface, \Serializable {
 	protected $updated;
 
 	/**
-	 * @var \Rapsys\UserBundle\Entity\Civility
+	 * @var Civility
 	 */
 	protected $civility;
 
 	/**
-	 * @var \Doctrine\Common\Collections\Collection
+	 * @var ArrayCollection
 	 */
 	protected $groups;
 
 	/**
 	 * Constructor
+	 *
+	 * @param string $mail The user mail
 	 */
-	public function __construct() {
+	public function __construct(string $mail) {
+		$this->mail = $mail;
 		$this->active = false;
+		$this->disabled = false;
 		$this->groups = new ArrayCollection();
 	}
 
@@ -77,7 +98,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return integer
 	 */
-	public function getId() {
+	public function getId(): int {
 		return $this->id;
 	}
 
@@ -88,7 +109,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setMail($mail) {
+	public function setMail(string $mail): User {
 		$this->mail = $mail;
 
 		return $this;
@@ -99,7 +120,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getMail() {
+	public function getMail(): ?string {
 		return $this->mail;
 	}
 
@@ -110,7 +131,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setPseudonym($pseudonym) {
+	public function setPseudonym(string $pseudonym): User {
 		$this->pseudonym = $pseudonym;
 
 		return $this;
@@ -121,7 +142,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getPseudonym() {
+	public function getPseudonym(): ?string {
 		return $this->pseudonym;
 	}
 
@@ -132,7 +153,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setForename($forename) {
+	public function setForename(string $forename): User {
 		$this->forename = $forename;
 
 		return $this;
@@ -143,7 +164,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getForename() {
+	public function getForename(): ?string {
 		return $this->forename;
 	}
 
@@ -154,7 +175,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setSurname($surname) {
+	public function setSurname(string $surname): User {
 		$this->surname = $surname;
 
 		return $this;
@@ -165,7 +186,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getSurname() {
+	public function getSurname(): ?string {
 		return $this->surname;
 	}
 
@@ -176,7 +197,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setPassword($password) {
+	public function setPassword(string $password): User {
 		$this->password = $password;
 
 		return $this;
@@ -189,7 +210,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getPassword() {
+	public function getPassword(): ?string {
 		return $this->password;
 	}
 
@@ -200,7 +221,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setActive($active) {
+	public function setActive(bool $active): User {
 		$this->active = $active;
 
 		return $this;
@@ -211,10 +232,32 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return bool
 	 */
-	public function getActive() {
+	public function getActive(): bool {
 		return $this->active;
 	}
 
+	/**
+	 * Set disabled
+	 *
+	 * @param bool $disabled
+	 *
+	 * @return User
+	 */
+	public function setDisabled(bool $disabled): User {
+		$this->disabled = $disabled;
+
+		return $this;
+	}
+
+	/**
+	 * Get disabled
+	 *
+	 * @return bool
+	 */
+	public function getDisabled(): bool {
+		return $this->disabled;
+	}
+
 	/**
 	 * Set created
 	 *
@@ -222,7 +265,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setCreated($created) {
+	public function setCreated(\DateTime $created): User {
 		$this->created = $created;
 
 		return $this;
@@ -233,7 +276,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return \DateTime
 	 */
-	public function getCreated() {
+	public function getCreated(): \DateTime {
 		return $this->created;
 	}
 
@@ -244,7 +287,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setUpdated($updated) {
+	public function setUpdated(\DateTime $updated): User {
 		$this->updated = $updated;
 
 		return $this;
@@ -255,14 +298,14 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return \DateTime
 	 */
-	public function getUpdated() {
+	public function getUpdated(): \DateTime {
 		return $this->updated;
 	}
 
 	/**
 	 * Set civility
 	 */
-	public function setCivility(Civility $civility) {
+	public function setCivility(Civility $civility): User {
 		$this->civility = $civility;
 
 		return $this;
@@ -278,7 +321,7 @@ class User implements UserInterface, \Serializable {
 	/**
 	 * Add group
 	 *
-	 * @param \Rapsys\UserBundle\Entity\Group $group
+	 * @param Group $group
 	 *
 	 * @return User
 	 */
@@ -291,7 +334,7 @@ class User implements UserInterface, \Serializable {
 	/**
 	 * Remove group
 	 *
-	 * @param \Rapsys\UserBundle\Entity\Group $group
+	 * @param Group $group
 	 */
 	public function removeGroup(Group $group) {
 		$this->groups->removeElement($group);
@@ -300,16 +343,16 @@ class User implements UserInterface, \Serializable {
 	/**
 	 * Get groups
 	 *
-	 * @return \Doctrine\Common\Collections\Collection
+	 * @return ArrayCollection
 	 */
-	public function getGroups() {
+	public function getGroups(): ArrayCollection {
 		return $this->groups;
 	}
 
 	/**
 	 * {@inheritdoc}
 	 */
-	public function getRoles() {
+	public function getRoles(): array {
 		//Get the unique roles list by id
 		return array_unique(array_reduce(
 			//Cast groups as array
@@ -329,7 +372,7 @@ class User implements UserInterface, \Serializable {
 	/**
 	 * {@inheritdoc}
 	 */
-	public function getRole() {
+	public function getRole(): ?string {
 		//Retrieve roles
 		$roles = $this->getRoles();
 
@@ -356,7 +399,7 @@ class User implements UserInterface, \Serializable {
 	/**
 	 * {@inheritdoc}
 	 */
-	public function getSalt() {
+	public function getSalt(): ?string {
 		//No salt required with bcrypt
 		return null;
 	}
@@ -364,14 +407,14 @@ class User implements UserInterface, \Serializable {
 	/**
 	 * {@inheritdoc}
 	 */
-	public function getUsername() {
+	public function getUsername(): string {
 		return $this->mail;
 	}
 
 	/**
 	 * {@inheritdoc}
 	 */
-	public function eraseCredentials() {}
+	public function eraseCredentials(): void {}
 
 	public function serialize(): string {
 		return serialize([
@@ -379,6 +422,7 @@ class User implements UserInterface, \Serializable {
 			$this->mail,
 			$this->password,
 			$this->active,
+			$this->disabled,
 			$this->created,
 			$this->updated
 		]);
@@ -390,16 +434,34 @@ class User implements UserInterface, \Serializable {
 			$this->mail,
 			$this->password,
 			$this->active,
+			$this->disabled,
 			$this->created,
 			$this->updated
 		) = unserialize($serialized);
 	}
 
-	//XXX: was from vendor/symfony/security-core/User/AdvancedUserInterface.php, see if it's used anymore
-	public function isEnabled() {
+	/**
+	 * Check if account is activated
+	 *
+	 * It was from deprecated AdvancedUserInterface, see if it's used anymore
+	 *
+	 * @see vendor/symfony/security-core/User/AdvancedUserInterface.php
+	 */
+	public function isActivated(): bool {
 		return $this->active;
 	}
 
+	/**
+	 * Check if account is disabled
+	 *
+	 * It was from deprecated AdvancedUserInterface, see if it's used anymore
+	 *
+	 * @see vendor/symfony/security-core/User/AdvancedUserInterface.php
+	 */
+	public function isDisabled(): bool {
+		return $this->disabled;
+	}
+
 	/**
 	 * {@inheritdoc}
 	 */